ExpressiveIcon class
An icon wrapped in a shaped, colored container (M3 Expressive style).
This doesn't replace Icon — it presents any icon in the expressive
container style used across M3 Expressive (nav indicators, FABs, etc.)
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- ExpressiveIcon
Constructors
-
ExpressiveIcon(IconData icon, {Key? key, ExpressiveIconSize size = ExpressiveIconSize.medium, Color? containerColor, Color? iconColor, List<
Offset> ? shape, ExpressiveShapeType shapeType = ExpressiveShapeType.rounded, bool filled = true, VoidCallback? onPressed, String? tooltip}) -
const
Properties
- containerColor → Color?
-
final
- filled → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → IconData
-
final
- iconColor → Color?
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- onPressed → VoidCallback?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
shape
→ List<
Offset> ? -
Custom shape points. Overrides shapeType if provided.
final
- shapeType → ExpressiveShapeType
-
final
- size → ExpressiveIconSize
-
final
- tooltip → String?
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited