WindowSizeClass enum

Window size class.

Inheritance
Available extensions

Values

compact → const WindowSizeClass
medium → const WindowSizeClass
expanded → const WindowSizeClass
large → const WindowSizeClass
extraLarge → const WindowSizeClass

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromWidth(double width) WindowSizeClass

Constants

values → const List<WindowSizeClass>
A constant List of the values in this enum, in order of their declaration.