ComponentMotion class
Per-component motion token assignment.
Different components use different spring configurations based on their visual prominence and interaction type.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- bottomSheet → ExpressiveSpring
-
Bottom sheets.
no setter
-
Buttons and interactive controls.
no setter
- card → ExpressiveSpring
-
Cards and containers.
no setter
- carousel → ExpressiveSpring
-
Carousel page transitions.
no setter
- dialog → ExpressiveSpring
-
Dialogs and overlays.
no setter
- icon → ExpressiveSpring
-
Icon animations.
no setter
- loading → ExpressiveSpring
-
Loading indicator effects.
no setter
- searchBar → ExpressiveSpring
-
Search bar expand/collapse.
no setter
- shapeMorph → ExpressiveSpring
-
Shape morphing transitions.
no setter
- snackbar → ExpressiveSpring
-
Snackbars and toasts.
no setter
- stateLayer → ExpressiveSpring
-
State layer (press/hover) effects.
no setter
Constants
- hero → const MotionScheme
- FAB and hero elements.
- Navigation transitions (tabs, rail, bottom nav).