ExpressiveRadiusTokens class
Corner radius tokens.
Constructors
Properties
- full → double
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- lg → double
-
final
- md → double
-
final
- none → double
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sm → double
-
final
- xl → double
-
final
- xs → double
-
final
- xxl → double
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- standard → const ExpressiveRadiusTokens